@@ -116,6 +116,8 @@ class URLChooser:
                      'C': self._clipboard,
                      'c': self._context,
                      'ctrl l': self._clear_screen,
+                     'ctrl f': self._page_down,
+                     'ctrl b': self._page_up,
                      'd': self._del_url,
                      'f1': self._help_menu,
                      'G': self._bottom,
@@ -546,6 +548,16 @@ class URLChooser:
         self.top.base_widget.body.focus_position = target_position
         self.top.base_widget.keypress(self.size, "")  # Trick urwid into redisplaying the cursor
 
+    def _page_up(self):
+        """ Ctrl-b """
+        self.top.base_widget.keypress(self.size, "page up")
+        self.top.base_widget.keypress(self.size, "")  # Trick urwid into redisplaying the cursor
+
+    def _page_down(self):
+        """ Ctrl-f """
+        self.top.base_widget.keypress(self.size, "page down")
+        self.top.base_widget.keypress(self.size, "")  # Trick urwid into redisplaying the cursor
+
     def _previous(self):
         """ K """
         current_position = self.top.base_widget.body.focus_position
